function [L,U,P]=permLU(A)
% FUNCTION fc_bench.demos.permLU 
% -- [L,U,P]=permLU(A)
%     Computes permuted LU factorization of A. 
%     L, U and P are respectively the lower triangular matrix with unit 
%     diagonal, the upper triangular matrix and the permutation matrix 
%     so that 
%         P*A = L*U.
%
  m=size(A,1);
  assert(size(A,1)==m)
  L=eye(m,m);
  p=1:m;
  U=A;
  for i=1:m
    [~,idx]=max(abs(U(i:end,i)));
    mu=idx(1)+i-1;
    if i~=mu
      U([i,mu],i:end)=U([mu,i],i:end);
      L([i,mu],1:i-1)=L([mu,i],1:i-1);
      p([i,mu])=p([mu,i]);
    end
    for j=i+1:m
      L(j,i)=U(j,i)/U(i,i);
      U(j,i:end)=U(j,i:end)-L(j,i)*U(i,i:end);
    end
  end
  P=zeros(m,m);P(sub2ind([m,m],1:m,p))=1;
end
